@@ -1,7 +1,7 @@
 package App::Wubot::Reactor::Command;
 use Moose;
 
-our $VERSION = '0.3.9'; # VERSION
+our $VERSION = '0.3.10'; # VERSION
 
 use FileHandle;
 use File::Path;
@@ -135,15 +135,20 @@ sub monitor {
 
     my $directory = $self->logdir;
 
+    my @entries;
+
     my $dir_h;
     opendir( $dir_h, $directory ) or $self->logger->logdie( "Can't opendir $directory: $!" );
-
   FILE:
     while ( defined( my $entry = readdir( $dir_h ) ) ) {
         next unless $entry;
         next if -d $entry;
-
         next unless $entry =~ m|\.log$|;
+        push @entries, $entry;
+    }
+    closedir( $dir_h );
+
+    for my $entry ( sort @entries ) {
         $self->logger->debug( "Command: found running entry: $entry" );
 
         my $id = $entry;
@@ -255,8 +260,6 @@ sub monitor {
         unlink( $logfile );
     }
 
-    closedir( $dir_h );
-
     $self->logger->debug( "Searching for processes in queue to be started" );
 
     my @queues;
@@ -493,7 +496,7 @@ App::Wubot::Reactor::Command - run an external command using data from the messa
 
 =head1 VERSION
 
-version 0.3.9
+version 0.3.10
 
 =head1 DESCRIPTION
 
